import django

SITE_ID = 1

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': ':memory:',
    }
}


if django.VERSION[:2] < (1, 6):
    TEST_RUNNER = 'discover_runner.DiscoverRunner'

SECRET_KEY = 'local'



from __future__ import absolute_import
from django.conf import settings
from django.test import SimpleTestCase
from django.test.client import RequestFactory
from teracy.html5boilerplate.context_processors import page


class ContextProcessorsTest(SimpleTestCase):
    def setUp(self):
        self.factory = RequestFactory()

    def tearDown(self):
        settings.SITE_AUTHOR = None
        settings.SITE_COPYRIGHT = None
        settings.SITE_GA_ID = None

    def test_module_api(self):
        """
        Tests module's defined APIs
        """
        self.assertIsNotNone(page,
                             'teracy.html5boilerplate.context_processors.page must be available')

    def test_empty_settings(self):
        """
        Tests that there is no settings, all default settings for
        SITE_AUTHOR
        SITE_COPYRIGHT
        SITE_GA_ID
        """
        request = self.factory.get('/')
        context_extras = page(request)
        self.assertIsInstance(context_extras, dict, 'context_extras must be a dict')

        page_context = context_extras['page']
        self.assertEqual(page_context, {}, 'page_context must be empty dict')

    def test_site_author(self):
        """
        Tests that only SITE_AUTHOR is defined
        """
        settings.SITE_AUTHOR = 'Teracy'
        request = self.factory.get('/')
        context_extras = page(request)
        page_context = context_extras['page']
        expected_page_context = {
            'author': settings.SITE_AUTHOR
        }
        self.assertEqual(page_context, expected_page_context,
                         "%s must be %s" % (page_context, expected_page_context))

    def test_site_copyright(self):
        """
        Tests that only SITE_COPYRIGHT is defined
        """
        settings.SITE_COPYRIGHT = 'Teracy, Inc'
        request = self.factory.get('/')
        context_extras = page(request)
        page_context = context_extras['page']
        expected_page_context = {
            'copyright': settings.SITE_COPYRIGHT
        }
        self.assertEqual(page_context, expected_page_context,
                         '%s must be %s' % (page_context, expected_page_context))

    def test_site_ga_id(self):
        """
        Tests that only SITE_GA_ID is defined
        """
        settings.SITE_GA_ID = 'UA-42868657-2'
        request = self.factory.get('/')
        context_extras = page(request)
        page_context = context_extras['page']
        expected_page_context = {
            'ga_id': settings.SITE_GA_ID
        }
        self.assertEqual(page_context, expected_page_context,
                         '%s must be %s' % (page_context, expected_page_context))

    def test_all(self):
        """
        Tests when all available settings are defined
        """
        settings.SITE_AUTHOR = 'Teracy'
        settings.SITE_COPYRIGHT = 'Teracy, Inc'
        settings.SITE_GA_ID = 'UA-42868657-2'

        request = self.factory.get('/')
        context_extras = page(request)
        page_context = context_extras['page']
        self.assertEqual(page_context['author'], settings.SITE_AUTHOR,
                         '%s must be %s' % (page_context['author'], settings.SITE_AUTHOR))
        self.assertEqual(page_context.get('copyright'), settings.SITE_COPYRIGHT,
                         '%s must be %s' % (page_context['copyright'], settings.SITE_COPYRIGHT))
        self.assertEqual(page_context['ga_id'], settings.SITE_GA_ID,
                         '%s must be %s' % (page_context['ga_id'], settings.SITE_GA_ID))

    def test_complex(self):
        """
        Tests when random settings are defined, complex cases
        """
        settings.SITE_AUTHOR = 'Teracy'
        settings.SITE_COPYRIGHT = 'Teracy, Inc'
        request = self.factory.get('/')
        context_extras = page(request)
        page_context = context_extras['page']

        self.assertEqual(page_context['author'], settings.SITE_AUTHOR,
                         '%s must be %s' % (page_context['author'], settings.SITE_AUTHOR))
        self.assertEqual(page_context['copyright'], settings.SITE_COPYRIGHT,
                         '%s must be %s' % (page_context['copyright'], settings.SITE_COPYRIGHT))



"""
A set of request context processors provied by teracy.html5boilerplate.
"""
from django.conf import settings


def page(request):
    """
    page context processor which adds default context to 'page' via settings module.

    settings.SITE_AUTHOR => page.author
    settings.SITE_COPYRIGHT => page.copyright
    settings.SITE_GA_ID => page.ga_id
    """

    context_extras = {}

    page_context = {}

    if settings.SITE_AUTHOR is not None:
        page_context['author'] = settings.SITE_AUTHOR

    if settings.SITE_COPYRIGHT is not None:
        page_context['copyright'] = settings.SITE_COPYRIGHT

    if settings.SITE_GA_ID is not None:
        page_context['ga_id'] = settings.SITE_GA_ID

    context_extras['page'] = page_context

    return context_extras



import os
import re
from setuptools import setup, find_packages


def get_file(*parts):
    filename = os.path.join(os.path.dirname(__file__), *parts)
    return open(filename)


def find_version(*file_paths):
    f = get_file(*file_paths)
    for line in f:
        if re.match('__version__ = .+', line):
            return re.search('\d.+\d', line).group(0)
    raise RuntimeError('Unable to find string version')


README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='teracy-django-html5-boilerplate',
    version=find_version('teracy', 'html5boilerplate', '__init__.py'),
    packages=find_packages(),
    namespace_packages=['teracy'],
    include_package_data=True,
    license='BSD License',
    description='html5-boilerplate Django wrapper application',
    long_description=README,
    url='http://djhbp.teracy.org',
    author='hoatle',
    author_email='hoatlevan@gmail.com',
    maintainer='hoatle',
    maintainer_email='hoatlevan@gmail.com',
    keywords=['python', 'django', 'html5-boilerplate'],
    install_requires=[
        'django>=1.5'
    ],
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Browsers',
    ]
)
